@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[141]:
+# In[423]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[142]:
+# In[422]:
 
 
-version = '0.97'
+version = '0.98'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[143]:
+# In[286]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[144]:
+# In[287]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[145]:
+# In[288]:
 
 
 def testPrint(*args):
@@ -64,7 +64,7 @@ def testPrint(*args):
 
 # # Inspect
 
-# In[146]:
+# In[289]:
 
 
 import inspect
@@ -76,7 +76,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[147]:
+# In[290]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -84,7 +84,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[148]:
+# In[291]:
 
 
 def shell(cmd):
@@ -97,7 +97,7 @@ def shell(cmd):
     return out
 
 
-# In[149]:
+# In[292]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -119,13 +119,13 @@ def bash(cmd, lineList=True):
 
 # # Timing
 
-# In[150]:
+# In[293]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[151]:
+# In[294]:
 
 
 def timeSinceLastCall(name):
@@ -138,14 +138,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[152]:
+# In[295]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[153]:
+# In[296]:
 
 
 import time
@@ -173,7 +173,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[154]:
+# In[297]:
 
 
 requirements = []
@@ -205,7 +205,7 @@ import yaml
 
 # # Strings
 
-# In[155]:
+# In[298]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -235,7 +235,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[156]:
+# In[299]:
 
 
 def strUuid4():
@@ -246,14 +246,14 @@ def strUuid4():
     return uuid
 
 
-# In[157]:
+# In[300]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[158]:
+# In[301]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -265,7 +265,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[159]:
+# In[302]:
 
 
 if is_testing():
@@ -274,7 +274,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[160]:
+# In[303]:
 
 
 def strMd5Pickle4(obj):
@@ -284,14 +284,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[161]:
+# In[304]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[162]:
+# In[305]:
 
 
 def strMd5String(s):
@@ -300,7 +300,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[163]:
+# In[306]:
 
 
 if is_testing():
@@ -309,7 +309,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[164]:
+# In[307]:
 
 
 def mapThread(func, args, n=8):
@@ -334,14 +334,14 @@ if is_testing():
 
 # # Lists
 
-# In[165]:
+# In[308]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[166]:
+# In[309]:
 
 
 if is_testing():
@@ -350,7 +350,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[167]:
+# In[310]:
 
 
 def liSplit(a, number_of_splits):
@@ -358,7 +358,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[168]:
+# In[311]:
 
 
 if is_testing():
@@ -370,7 +370,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[169]:
+# In[312]:
 
 
 def liJoin(l):
@@ -380,14 +380,14 @@ def liJoin(l):
     return out
 
 
-# In[170]:
+# In[313]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[171]:
+# In[314]:
 
 
 def liFlatten(l):
@@ -404,7 +404,7 @@ def liFlatten(l):
         return l
 
 
-# In[172]:
+# In[315]:
 
 
 if is_testing():
@@ -414,7 +414,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[173]:
+# In[316]:
 
 
 regex_cache = {}
@@ -424,35 +424,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[174]:
+# In[317]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[175]:
+# In[318]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[176]:
+# In[319]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[177]:
+# In[320]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[178]:
+# In[321]:
 
 
 def lCsv(l, force_oneline=False):
@@ -468,21 +468,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[179]:
+# In[322]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[180]:
+# In[323]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[181]:
+# In[324]:
 
 
 if is_testing():
@@ -491,7 +491,7 @@ if is_testing():
 
 # # Text files
 
-# In[182]:
+# In[325]:
 
 
 def txtread(path):
@@ -512,7 +512,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[183]:
+# In[326]:
 
 
 if is_testing():
@@ -521,21 +521,21 @@ if is_testing():
 
 # # YAML files
 
-# In[184]:
+# In[327]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[185]:
+# In[328]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[186]:
+# In[329]:
 
 
 if is_testing():
@@ -548,7 +548,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[187]:
+# In[330]:
 
 
 regex_cache = {}
@@ -560,35 +560,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[188]:
+# In[331]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[189]:
+# In[332]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[190]:
+# In[333]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[191]:
+# In[334]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[192]:
+# In[335]:
 
 
 if is_testing():
@@ -597,7 +597,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[193]:
+# In[336]:
 
 
 import warnings
@@ -621,7 +621,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[194]:
+# In[337]:
 
 
 def gsGsToHttp(path):
@@ -631,7 +631,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[195]:
+# In[338]:
 
 
 def gsLs(path):
@@ -641,7 +641,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[196]:
+# In[339]:
 
 
 def gsExists(path):
@@ -651,7 +651,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[197]:
+# In[340]:
 
 
 def gsUploadFile(gsPath, path):
@@ -659,7 +659,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[198]:
+# In[341]:
 
 
 def gsTxtread(path):
@@ -671,7 +671,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[199]:
+# In[342]:
 
 
 def gsTxtwrite(path, s):
@@ -679,7 +679,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[200]:
+# In[343]:
 
 
 def gsImwrite(path, img):
@@ -688,7 +688,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[201]:
+# In[344]:
 
 
 def gsImread(path):
@@ -697,7 +697,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[202]:
+# In[345]:
 
 
 def gsPklWrite(path, obj):
@@ -705,7 +705,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[203]:
+# In[346]:
 
 
 def gsPklRead(path):
@@ -715,7 +715,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[204]:
+# In[347]:
 
 
 def pklwrite(path, obj):
@@ -728,7 +728,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[205]:
+# In[348]:
 
 
 def pklread(path):
@@ -739,7 +739,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[206]:
+# In[349]:
 
 
 if is_testing():
@@ -752,7 +752,7 @@ if is_testing():
 
 # # Images
 
-# In[207]:
+# In[350]:
 
 
 def _imreadSsh(path):
@@ -813,7 +813,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[208]:
+# In[351]:
 
 
 def imscaleNN(img, s):
@@ -825,7 +825,7 @@ def imscaleBic(img, s):
 
 
 
-# In[209]:
+# In[352]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -840,14 +840,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[210]:
+# In[353]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[211]:
+# In[354]:
 
 
 if is_testing():
@@ -855,7 +855,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[212]:
+# In[355]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -894,7 +894,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[213]:
+# In[356]:
 
 
 def imDecodeBytes(imBytes):
@@ -905,7 +905,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[214]:
+# In[357]:
 
 
 #if is_testing():
@@ -913,14 +913,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[215]:
+# In[358]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[216]:
+# In[359]:
 
 
 if is_testing():
@@ -939,7 +939,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[217]:
+# In[360]:
 
 
 def imRepeat(img, height, width):
@@ -953,7 +953,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[218]:
+# In[361]:
 
 
 if is_testing():
@@ -961,33 +961,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[219]:
+# In[362]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[220]:
+# In[363]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[221]:
+# In[364]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[222]:
+# In[365]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[223]:
+# In[366]:
 
 
 def imAddNoiseGauss(img, std):
@@ -999,7 +999,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[224]:
+# In[367]:
 
 
 if is_testing():
@@ -1007,7 +1007,7 @@ if is_testing():
     imshow('/tmp/img.jpg')
 
 
-# In[225]:
+# In[368]:
 
 
 def imJpgDegradation(img, quality):
@@ -1020,7 +1020,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[226]:
+# In[369]:
 
 
 def imCropCenter(img, size):
@@ -1035,35 +1035,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[227]:
+# In[370]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[228]:
+# In[371]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[229]:
+# In[372]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[230]:
+# In[373]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[231]:
+# In[374]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1086,7 +1086,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[232]:
+# In[375]:
 
 
 #if is_testing(): 
@@ -1096,7 +1096,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[233]:
+# In[376]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
@@ -1140,7 +1140,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
     return out
 
 
-# In[234]:
+# In[377]:
 
 
 if is_testing():
@@ -1148,7 +1148,7 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[235]:
+# In[378]:
 
 
 if is_testing():
@@ -1162,7 +1162,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1, n_rows=2))
 
 
-# In[236]:
+# In[379]:
 
 
 #if is_testing():
@@ -1170,7 +1170,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[237]:
+# In[380]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1207,7 +1207,7 @@ if is_testing():
 
 # # Video
 
-# In[238]:
+# In[381]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1227,33 +1227,33 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
-# In[239]:
+# In[382]:
 
 
 #ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
 
 
-# In[280]:
+# In[421]:
 
 
 def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
     with tempfile.TemporaryDirectory() as d:
         for idx, img in enumerate(imgs):
             imwrite(os.path.join(d, f"img{idx:09d}.png"), img)
-        out = bash(f"cd {d} && ls && ffmpeg -framerate 5 -i img%09d.png -c:v libx264 -r 30 -pix_fmt yuv420p {path} -y")
+        out = bash(f"cd {d} && ls && ffmpeg -framerate {1/time_per_image} -i img%09d.png -c:v libx264 -r 30 -pix_fmt yuv420p {path} -y")
         if verbose:
             print(out)
 
 if is_testing():
     imgs = [imNewNoise(40, 40) for _ in range(48)]
     path = '/tmp/out.mp4'
-    imsToMp4(path, imgs, 1/10)
+    imsToMp4(path, imgs, 1/10, verbose=1)
     print(path)
 
 
 # # pytorch
 
-# In[241]:
+# In[384]:
 
 
 def ptT(img_np_uint8):
@@ -1270,7 +1270,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[242]:
+# In[385]:
 
 
 if is_testing():
@@ -1282,7 +1282,7 @@ if is_testing():
 
 # # Files
 
-# In[243]:
+# In[386]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1303,7 +1303,7 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[244]:
+# In[387]:
 
 
 if is_testing():
@@ -1332,7 +1332,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[245]:
+# In[388]:
 
 
 def fiRemove(path):
@@ -1360,7 +1360,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[246]:
+# In[389]:
 
 
 if is_testing():
@@ -1392,7 +1392,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[247]:
+# In[390]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1407,7 +1407,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[248]:
+# In[391]:
 
 
 def fiJoin(*args):
@@ -1419,7 +1419,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[249]:
+# In[392]:
 
 
 def jnSettings():
@@ -1430,7 +1430,7 @@ if is_testing():
     jnSettings()
 
 
-# In[250]:
+# In[393]:
 
 
 def jnNbFullWidth():
@@ -1444,7 +1444,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[251]:
+# In[394]:
 
 
 def jnImageRenderingPixelated():
@@ -1456,7 +1456,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[252]:
+# In[395]:
 
 
 def jnDefault():
@@ -1474,7 +1474,7 @@ if is_testing():
 
 
 
-# In[253]:
+# In[396]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1487,7 +1487,7 @@ if is_testing():
     
 
 
-# In[254]:
+# In[397]:
 
 
 def jnImgToHtmlB64(img):
@@ -1522,7 +1522,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[255]:
+# In[398]:
 
 
 if is_testing():
@@ -1530,7 +1530,7 @@ if is_testing():
    
 
 
-# In[256]:
+# In[399]:
 
 
 if is_testing():
@@ -1540,7 +1540,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[257]:
+# In[400]:
 
 
 
@@ -1550,7 +1550,7 @@ if is_testing():
 
 # # GIT
 
-# In[258]:
+# In[401]:
 
 
 def gitGetHash():
@@ -1560,7 +1560,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[259]:
+# In[402]:
 
 
 def gitGetBranch():
@@ -1570,7 +1570,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[260]:
+# In[403]:
 
 
 def gitGetMessage():
@@ -1580,7 +1580,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[261]:
+# In[404]:
 
 
 def gitGetAllFiles():
@@ -1590,7 +1590,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[262]:
+# In[405]:
 
 
 def gitListByTime(path=None):
@@ -1606,7 +1606,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[263]:
+# In[406]:
 
 
 def gitTime(path):
@@ -1617,7 +1617,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[264]:
+# In[407]:
 
 
 def gitTimeRaw(path):
@@ -1628,7 +1628,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[265]:
+# In[408]:
 
 
 def shellSortDirsBySize():
@@ -1640,14 +1640,14 @@ if is_testing():
 
 # # Package Files
 
-# In[266]:
+# In[409]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[267]:
+# In[410]:
 
 
 def shell(cmd):
@@ -1655,7 +1655,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[268]:
+# In[411]:
 
 
 if is_testing():
@@ -1687,7 +1687,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[269]:
+# In[412]:
 
 
 if is_testing():
@@ -1697,7 +1697,7 @@ description-file = README.md
 """
 
 
-# In[270]:
+# In[413]:
 
 
 if is_testing():
@@ -1720,14 +1720,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[271]:
+# In[414]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[275]:
+# In[415]:
 
 
 if is_testing():
@@ -1738,7 +1738,7 @@ if is_testing():
     print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[276]:
+# In[416]:
 
 
 if is_testing():
@@ -1749,7 +1749,7 @@ lx/__init__.py
 """
 
 
-# In[277]:
+# In[417]:
 
 
 if is_testing():
